/********************************************************************************
** Form generated from reading UI file 'timeedit.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TIMEEDIT_H
#define UI_TIMEEDIT_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include <kpluralhandlingspinbox.h>

QT_BEGIN_NAMESPACE

class Ui_TimeEditWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *minutesLabel_2;
    KPluralHandlingSpinBox *minutes;
    KPluralHandlingSpinBox *seconds;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *TimeEditWidget)
    {
        if (TimeEditWidget->objectName().isEmpty())
            TimeEditWidget->setObjectName("TimeEditWidget");
        TimeEditWidget->resize(267, 52);
        gridLayout = new QGridLayout(TimeEditWidget);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        minutesLabel_2 = new QLabel(TimeEditWidget);
        minutesLabel_2->setObjectName("minutesLabel_2");

        gridLayout->addWidget(minutesLabel_2, 0, 0, 1, 1);

        minutes = new KPluralHandlingSpinBox(TimeEditWidget);
        minutes->setObjectName("minutes");
        minutes->setFocusPolicy(Qt::WheelFocus);
        minutes->setMaximum(1440);
        minutes->setValue(3);

        gridLayout->addWidget(minutes, 0, 1, 1, 1);

        seconds = new KPluralHandlingSpinBox(TimeEditWidget);
        seconds->setObjectName("seconds");
        seconds->setMaximum(59);

        gridLayout->addWidget(seconds, 0, 3, 1, 1);

        spacerItem = new QSpacerItem(5, 5, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 0, 5, 1, 1);

        spacerItem1 = new QSpacerItem(16, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem1, 1, 0, 1, 4);


        retranslateUi(TimeEditWidget);

        QMetaObject::connectSlotsByName(TimeEditWidget);
    } // setupUi

    void retranslateUi(QWidget *TimeEditWidget)
    {
        TimeEditWidget->setWindowTitle(tr2i18n("Custom Tea", nullptr));
        minutesLabel_2->setText(tr2i18n("Tea time:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TimeEditWidget: public Ui_TimeEditWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TIMEEDIT_H

