/********************************************************************************
** Form generated from reading UI file 'settings.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGS_H
#define UI_SETTINGS_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include <kpluralhandlingspinbox.h>

QT_BEGIN_NAMESPACE

class Ui_SettingsWidget
{
public:
    QGridLayout *gridLayout;
    QGroupBox *kbuttongroup1;
    QVBoxLayout *vboxLayout;
    QTreeView *tealistTreeView;
    QHBoxLayout *hboxLayout;
    QToolButton *newButton;
    QToolButton *removeButton;
    QToolButton *upButton;
    QToolButton *downButton;
    QSpacerItem *spacerItem;
    QGroupBox *teaPropertiesGroup;
    QGridLayout *gridLayout1;
    QLabel *label;
    QLineEdit *teaNameEdit;
    QLabel *label_7;
    QSpinBox *minutesSpin;
    QLabel *label_3;
    QSpinBox *secondsSpin;
    QLabel *label_4;
    QSpacerItem *spacerItem1;
    QGroupBox *kbuttongroup2;
    QVBoxLayout *verticalLayout;
    QCheckBox *popupCheckBox;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *spacerItem2;
    QCheckBox *autohideCheckBox;
    KPluralHandlingSpinBox *autohideSpinBox;
    QSpacerItem *spacerItem3;
    QHBoxLayout *hboxLayout2;
    QCheckBox *reminderCheckBox;
    KPluralHandlingSpinBox *reminderSpinBox;
    QSpacerItem *spacerItem4;
    QCheckBox *visualizeCheckBox;

    void setupUi(QWidget *SettingsWidget)
    {
        if (SettingsWidget->objectName().isEmpty())
            SettingsWidget->setObjectName("SettingsWidget");
        SettingsWidget->resize(599, 535);
        gridLayout = new QGridLayout(SettingsWidget);
        gridLayout->setObjectName("gridLayout");
        kbuttongroup1 = new QGroupBox(SettingsWidget);
        kbuttongroup1->setObjectName("kbuttongroup1");
        vboxLayout = new QVBoxLayout(kbuttongroup1);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(-1, 0, -1, -1);
        tealistTreeView = new QTreeView(kbuttongroup1);
        tealistTreeView->setObjectName("tealistTreeView");
        tealistTreeView->setRootIsDecorated(false);
        tealistTreeView->setItemsExpandable(false);

        vboxLayout->addWidget(tealistTreeView);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        newButton = new QToolButton(kbuttongroup1);
        newButton->setObjectName("newButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        newButton->setIcon(icon);
        newButton->setAutoRaise(true);

        hboxLayout->addWidget(newButton);

        removeButton = new QToolButton(kbuttongroup1);
        removeButton->setObjectName("removeButton");
        removeButton->setEnabled(true);
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        removeButton->setIcon(icon1);
        removeButton->setAutoRaise(true);

        hboxLayout->addWidget(removeButton);

        upButton = new QToolButton(kbuttongroup1);
        upButton->setObjectName("upButton");
        upButton->setEnabled(true);
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("arrow-up")));
        upButton->setIcon(icon2);
        upButton->setAutoRaise(true);

        hboxLayout->addWidget(upButton);

        downButton = new QToolButton(kbuttongroup1);
        downButton->setObjectName("downButton");
        downButton->setEnabled(true);
        downButton->setAutoFillBackground(false);
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("arrow-down")));
        downButton->setIcon(icon3);
        downButton->setAutoRaise(true);

        hboxLayout->addWidget(downButton);

        spacerItem = new QSpacerItem(1, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);


        vboxLayout->addLayout(hboxLayout);


        gridLayout->addWidget(kbuttongroup1, 0, 0, 2, 1);

        teaPropertiesGroup = new QGroupBox(SettingsWidget);
        teaPropertiesGroup->setObjectName("teaPropertiesGroup");
        teaPropertiesGroup->setEnabled(false);
        gridLayout1 = new QGridLayout(teaPropertiesGroup);
        gridLayout1->setObjectName("gridLayout1");
        label = new QLabel(teaPropertiesGroup);
        label->setObjectName("label");

        gridLayout1->addWidget(label, 0, 0, 1, 1);

        teaNameEdit = new QLineEdit(teaPropertiesGroup);
        teaNameEdit->setObjectName("teaNameEdit");
        teaNameEdit->setEnabled(false);

        gridLayout1->addWidget(teaNameEdit, 0, 1, 1, 4);

        label_7 = new QLabel(teaPropertiesGroup);
        label_7->setObjectName("label_7");

        gridLayout1->addWidget(label_7, 1, 0, 1, 1);

        minutesSpin = new QSpinBox(teaPropertiesGroup);
        minutesSpin->setObjectName("minutesSpin");
        minutesSpin->setEnabled(false);
        minutesSpin->setMaximum(1440);

        gridLayout1->addWidget(minutesSpin, 1, 1, 1, 1);

        label_3 = new QLabel(teaPropertiesGroup);
        label_3->setObjectName("label_3");

        gridLayout1->addWidget(label_3, 1, 2, 1, 1);

        secondsSpin = new QSpinBox(teaPropertiesGroup);
        secondsSpin->setObjectName("secondsSpin");
        secondsSpin->setEnabled(false);
        secondsSpin->setMaximum(59);

        gridLayout1->addWidget(secondsSpin, 1, 3, 1, 1);

        label_4 = new QLabel(teaPropertiesGroup);
        label_4->setObjectName("label_4");

        gridLayout1->addWidget(label_4, 1, 4, 1, 1);


        gridLayout->addWidget(teaPropertiesGroup, 0, 1, 1, 1);

        spacerItem1 = new QSpacerItem(21, 81, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem1, 1, 1, 1, 1);

        kbuttongroup2 = new QGroupBox(SettingsWidget);
        kbuttongroup2->setObjectName("kbuttongroup2");
        verticalLayout = new QVBoxLayout(kbuttongroup2);
        verticalLayout->setObjectName("verticalLayout");
        popupCheckBox = new QCheckBox(kbuttongroup2);
        popupCheckBox->setObjectName("popupCheckBox");
        popupCheckBox->setChecked(true);

        verticalLayout->addWidget(popupCheckBox);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        spacerItem2 = new QSpacerItem(16, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem2);

        autohideCheckBox = new QCheckBox(kbuttongroup2);
        autohideCheckBox->setObjectName("autohideCheckBox");
        autohideCheckBox->setEnabled(true);
        autohideCheckBox->setChecked(false);

        hboxLayout1->addWidget(autohideCheckBox);

        autohideSpinBox = new KPluralHandlingSpinBox(kbuttongroup2);
        autohideSpinBox->setObjectName("autohideSpinBox");
        autohideSpinBox->setEnabled(false);
        autohideSpinBox->setMinimumSize(QSize(120, 0));
        autohideSpinBox->setMinimum(1);
        autohideSpinBox->setMaximum(300);
        autohideSpinBox->setValue(30);

        hboxLayout1->addWidget(autohideSpinBox);

        spacerItem3 = new QSpacerItem(151, 24, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem3);


        verticalLayout->addLayout(hboxLayout1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName("hboxLayout2");
        reminderCheckBox = new QCheckBox(kbuttongroup2);
        reminderCheckBox->setObjectName("reminderCheckBox");

        hboxLayout2->addWidget(reminderCheckBox);

        reminderSpinBox = new KPluralHandlingSpinBox(kbuttongroup2);
        reminderSpinBox->setObjectName("reminderSpinBox");
        reminderSpinBox->setEnabled(false);
        reminderSpinBox->setMinimumSize(QSize(120, 0));
        reminderSpinBox->setMinimum(1);
        reminderSpinBox->setMaximum(300);
        reminderSpinBox->setValue(60);

        hboxLayout2->addWidget(reminderSpinBox);

        spacerItem4 = new QSpacerItem(181, 25, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem4);


        verticalLayout->addLayout(hboxLayout2);


        gridLayout->addWidget(kbuttongroup2, 2, 0, 1, 2);

        visualizeCheckBox = new QCheckBox(SettingsWidget);
        visualizeCheckBox->setObjectName("visualizeCheckBox");
        visualizeCheckBox->setChecked(true);

        gridLayout->addWidget(visualizeCheckBox, 3, 0, 1, 2);


        retranslateUi(SettingsWidget);
        QObject::connect(autohideCheckBox, &QCheckBox::toggled, autohideSpinBox, &KPluralHandlingSpinBox::setEnabled);
        QObject::connect(reminderCheckBox, &QCheckBox::toggled, reminderSpinBox, &KPluralHandlingSpinBox::setEnabled);

        QMetaObject::connectSlotsByName(SettingsWidget);
    } // setupUi

    void retranslateUi(QWidget *SettingsWidget)
    {
        kbuttongroup1->setTitle(tr2i18n("Tea List", nullptr));
        teaPropertiesGroup->setTitle(tr2i18n("Tea Properties", nullptr));
        label->setText(tr2i18n("Name", nullptr));
        label_7->setText(tr2i18n("Time", nullptr));
        label_3->setText(tr2i18n("min", nullptr));
        label_4->setText(tr2i18n("sec", nullptr));
        kbuttongroup2->setTitle(tr2i18n("Action", nullptr));
        popupCheckBox->setText(tr2i18n("Popup", nullptr));
        autohideCheckBox->setText(tr2i18n("Auto hide popup after", nullptr));
        reminderCheckBox->setText(tr2i18n("Reminder every", nullptr));
        visualizeCheckBox->setText(tr2i18n("Visualize progress in icon tray", nullptr));
        (void)SettingsWidget;
    } // retranslateUi

};

namespace Ui {
    class SettingsWidget: public Ui_SettingsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGS_H

